/*IO Bit-Einzelzugriff */
// cbi -> clear bit
#define cbi(PORTx,bit) ( PORTx&=~(1<<(bit)) )

// sbi -> set bit
#define sbi(PORTx,bit) ( PORTx|=(1<<(bit)) )

// bit_is_set -> ist das Bit gesetzt?
//#define bit_is_set(PINx, bit) ( PINx&(1<<(bit)) )

// bit_is_clear -> ist das Bit gelscht?
//#define bit_is_clear(PINx, bit) ( !(PINx&(1<<(bit))) )

// loop_until_bit_is_set -> warte solange bis das bit gesetzt ist
//#define loop_until_bit_is_set(PxIN, bit) do { } while( bit_is_clear(PxIN, bit) )

// loop_until_bit_is_clear -> warte solange bis das bit gelscht ist
//#define loop_until_bit_is_clear(PINx, bit) do { } while( bit_is_set(PINx, bit) )

//		BIN 		HEX 	DEC Umrechnung fr 8 Bit
//Keiner	00000000	0x00	0
//0.PORT	00000001	0x01	1
//1.PORT	00000010	0x02	2
//2.PORT	00000100	0x04	4
//3.PORT	00001000	0x08	8
//4.PORT	00010000	0x10	16
//5.PORT	00100000	0x20	32
//6.PORT	01000000	0x40	64
//7.PORT	10000000	0x80	128
//ALLE		11111111	0xFF	255

// Als Ergnzung: Umstndlich, aber fr andere Compiler kompatibel
// Bsp. 1:
// DDRB = 0x1F;			-> 00011111		8-6 IN, 5-1 OUT
// PORTB = PORTB | 0x01;	-> setzten des 2. Bits durch Veroderung
// PORTB = PORTB & ~(0x01)	-> lschen des 2. Bits durch inverse Verundung
// Bsp. 2:
// DDRB = 0x1F;			-> 00011111		7-5 IN, 4-0 OUT
// PORTB = PORTB | 0x10		-> setzen des 4. Bits durch Veroderung
// PORTB = PORTB & ~(0x10)	-> lschen des 4. Bits durch inverse Verundung
// Bsp. 3:
// DDRB = 0x1F;			-> 00011111		7-5 IN, 4-0 OUT
// PORTB = PORTB | (1<<5)	-> setzen des 4. Bits durch Veroderung (1 wird um 5 nach links geshiftet)
// PORTB = PORTB & ~(1<<5)	-> lschen des 4. Bits durch inverse Verundung (1 wird um 5 nach links geshiftet)

/* PORT-DEFINITION Block Ende */

/* TYP-DEFINITION Block-Anfang*/
// 8 BIT = 1 Byte
typedef unsigned			char		BYTE;	//0..255
typedef unsigned 			char 		u08;	//0..255
typedef 					char 		s08;	//-128..127
// 16 BIT = 2 Byte = 1 Word
typedef unsigned			int		WORD;	//0..65535
typedef unsigned    		int		u16;	//0..65535
typedef 					int		s16;	//-32768..32767
// 32BIT = 4 Byte = 1 DWord
typedef unsigned			long int	DWORD;	//0..4*10^9
typedef unsigned			long int	u32;	//0..4*10^9
typedef 					long int	s32;	//-2*10^9..20*10^9
							//float = +-10^-37..+-10^38
// 64BIT = 8 Byte			//double = +-10^-307..+-10^308
										
/*
PA7	ADC7_NTC_100k
PA6	ADC6_ANINA
PA5	ADC5_ANINB

PB4 	DO1_Reseve
PB3	DO2_Solid_State_Relay
PB2	DI_SW2
PB1	DI_SW1
PB1	DI_SW0

PD7	DI_DATA_Thermoelement
PD6	DO_Clock_Thermoelement
PD5	PWMA
PD4	PWMB_LED1
PD3	DO_Enable_Thermoelement
PD2	DO_LED2
PD1	DO_TXD
PD0	DI_RXD
*/

//Ausgnge definieren
#define DO1_RESERVE_ON					sbi(PORTB, 4)
#define DO1_RESERVE_OFF					cbi(PORTB, 4)
#define DO2_SOLID_STATE_ON				sbi(PORTB, 5)
#define DO2_SOLID_STATE_OFF				cbi(PORTB, 5)
#define DO_Clock_THERMOELEMENT_ON		sbi(PORTD, 6)
#define DO_Clock_THERMOELEMENT_OFF		cbi(PORTD, 6)
#define PWMA_ON							sbi(PORTD, 5)
#define PWMA_OFF						cbi(PORTD, 5)
#define PWMB_LED1_ON					sbi(PORTD, 4)
#define PWMB_LED1_OFF					cbi(PORTD, 4)
#define DO_EN_THERMOELEMENT_ON			sbi(PORTD, 3)
#define DO_EN_THERMOELEMENT_OFF			cbi(PORTD, 3)
#define DO_LED2_ON						sbi(PORTD, 2)
#define DO_LED2_OFF						cbi(PORTD, 2)
#define TXD_ON							sbi(PORTD, 1)
#define TXD_OFF							cbi(PORTD, 1)

//Eingnge definieren
#define IS_DI_SW2_HIGH 					bit_is_set(PINB,2)
#define IS_DI_SW2_LOW 					bit_is_clear(PINB,2)
#define IS_DI_SW1_HIGH 					bit_is_set(PINB,1)
#define IS_DI_SW1_LOW 					bit_is_clear(PINB,1)
#define IS_DI_SW0_HIGH 					bit_is_set(PINB,0)
#define IS_DI_SW0_LOW 					bit_is_clear(PINB,0)
#define IS_DI_DATA_THERMOELEMENT_HIGH 	bit_is_set(PIND,7)
#define IS_DI_DATA_THERMOELEMENT_LOW 	bit_is_clear(PIND,7)
#define IS_RX_HIGH 						bit_is_set(PIND,0)
#define IS_RX_LOW 						bit_is_clear(PIND,0)
