#include <avr/io.h>
#include <util/delay.h>
#include "mylcd.h"
#include "small_font.h"
#include "bigChar.h"
#include "image_load.h"
#include "iodefinition.h"
#include <inttypes.h>
#include <avr/io.h>
#include <avr/pgmspace.h>
#include <avr/interrupt.h>
#include <stdlib.h>
#include <string.h>

//Cristal -> 16.000.000Hz
//F_CPU ist im makefile des Projekts mit 16MHz definiert!!!
#define BAUD 19200L
#define MYUBRR (F_CPU/(BAUD*16l)-1)
#define UBRR_VAL ((F_CPU+BAUD*8)/(BAUD*16)-1) 	

// Funktionsdeklarationen ANFANG
void IoDirection_Init(void);
void USART_Init(void);
void ADC_Init(void);
uint16_t ADC_Read(uint8_t, uint8_t);
void USART_putc(uint8_t);
void USART_puts(char *);
void USART_putf(float, int, int);
void USART_puti(int, int);
void USART_putui(unsigned int, int);
void USART_putui_0(unsigned int, int);
void USART_putui_hex(unsigned int, int);
void USART_putui_bin(unsigned int, int);
void USART_putb(uint8_t);
void wait_ms(uint16_t);
uint16_t takeTemperature(void);
void zeichneRohDiagramm(void);
// Funktionsdeklarationen ENDE

int main (void)
{
	uint8_t loop;
	uint16_t loopCounter=0;
	uint8_t xCounter=0;
	uint8_t yCounter=0;
	uint16_t analogWert=0;
	uint16_t temperature=0;	

	uint16_t deltaTemperatur=0;
	uint16_t t155GC=155;
	uint16_t startTemperatur=0;
	uint16_t neueSollwertTemperatur=0;

	//Initialisierungsroutinen
	IoDirection_Init();
	USART_Init();
	ADC_Init();

	//Thermoelement vorbereiten
	DO_EN_THERMOELEMENT_ON;
	DO_Clock_THERMOELEMENT_OFF;

	/*

	for(;;)
	{

		loopCounter++;

		wait_ms(50);
		DO_LED2_ON; PWMB_LED1_OFF;
		wait_ms(50);
		DO_LED2_OFF; PWMB_LED1_ON;

		/*
		USART_puts("Counter= ");
		USART_putui_0(loopCounter, 5);
		USART_putc('\n');
		USART_putc('\r');
		wait_ms(250);

		
		USART_putc('T');
		USART_putc('E');
		USART_putc('S');
		USART_putc('T');
		USART_putc('\n');
		USART_putc('\r');

		analogWert = ADC_Read(7, 10);
		USART_puts("AN7= ");
		USART_putui_0(analogWert, 5);
		wait_ms(250);
		USART_putc('\n');
		USART_putc('\r');
		USART_puts("AN6= ");
		analogWert = ADC_Read(6, 10);
		USART_putui_0(analogWert, 5);
		wait_ms(250);
		USART_putc('\n');
		USART_putc('\r');
		USART_puts("AN5= ");
		analogWert = ADC_Read(5, 10);
		USART_putui_0(analogWert, 5);
		wait_ms(250);
		USART_putc('\n');
		USART_putc('\r');
	

		temperature = takeTemperature();
		USART_puts("Temperature[C]= ");
		USART_putui_0(temperature, 4);
		USART_putc('\n');
		USART_putc('\r');
		wait_ms(250);




	}

	*/

	//init lcd
	lcd_init();
	lcd_clear();

	// draw sandwatch
	lcd_draw_fullscreen_bmp(img);


	for(;;)
	{
		wait_ms(50);
		DO_LED2_ON; PWMB_LED1_OFF;
		wait_ms(50);
		DO_LED2_OFF; PWMB_LED1_ON;
	}

	// draw progressbar
	lcd_draw_rect(22,23,100,16,BLACK);		
	for(loop=6;loop<=96;loop+=10)
	{
		_delay_ms(40);
		lcd_fill_rect (24,25,loop,12,BLACK);	// fill progressbar
	}		
	for(loop=0;loop<=100;loop++,_delay_ms(40));
	
	lcd_clear();				// clear screen
	lcd_set_cursor(0,LINE0);	// set cursor position
	lcd_putc(small_font,'1');	// draw some singel chars
	lcd_putc(small_font,'2');
	lcd_putc(small_font,'3');

	lcd_set_cursor(0,LINE1);					// new start position
	lcd_puts(small_font,"String using RAM");	// draw string using internal ram (better use lcd_puts_p)
	lcd_draw_line(0,LINE2,127,LINE2,BLACK);		// draw a line under the text

	lcd_set_cursor(0,LINE2+1);							// you can write text were you want (not only on lines)
	lcd_puts_p(small_font,PSTR("String from FLASH"));	// put string from flash memory
	
	lcd_set_cursor(30,LINE3+1);										// new pos
	lcd_puts_p(small_font,PSTR("String is bigger than screen"));	// strings bigger than the screen don't cause problems (the are cleanly cutted)

	lcd_set_cursor(10,LINE3+2);										// new pos
	lcd_puts_p(mega,PSTR("1"));										// a very big char

	lcd_set_cursor(30,LINE4+1);										// new pos
	lcd_puts_p(small_font,PSTR("You can use big Fonts"));			// mor text
	
	lcd_draw_rect(30,40,20,20,BLACK);	// draw a rectangle

	lcd_fill_rect(52,40,20,20,BLACK);	// a black filled rectangle
	lcd_fill_rect(52,40,10,10,WHITE);	// put two white rectangles into it
	lcd_fill_rect(62,50,10,10,WHITE);

	

	lcd_fill_rect(74,40,20,20,BLACK);	// do it again with a border
	lcd_fill_rect(74,40,10,10,WHITE);
	lcd_fill_rect(84,50,10,10,WHITE);
	lcd_draw_rect(74,40,20,20,BLACK);

	for(loop=0;loop<255;loop++,_delay_ms(40));

	lcd_clear();						// a new screen with text

	lcd_set_cursor(0,LINE2);
	lcd_puts_p(small_font,PSTR("Feel free to use this !"));
	lcd_set_cursor(0,LINE3);
	lcd_puts_p(small_font,PSTR("Everything is under GNU-GPL"));

	lcd_set_cursor(0,LINE6);
	lcd_puts_p(small_font,PSTR("Andre Fabricius --- 2008"));
	lcd_set_cursor(0,LINE7);
	lcd_puts_p(small_font,PSTR("mailto: master.andre@web.de"));

	for(loop=0;loop<=100;loop++,_delay_ms(40));
	lcd_invert();						// invert the hole screen an put it in inverted mode

	lcd_set_cursor(0,LINE0);
	lcd_puts_p(small_font,PSTR("Now we're in inverted mode"));
	lcd_draw_line(0,LINE1,127,LINE1,BLACK);

	for(loop=0;loop<=100;loop++,_delay_ms(40));
	lcd_fill_rect(0,0,127,LINE1,WHITE);	

	for(loop=0;loop<=64;loop++)
	{
		lcd_write_cmd(LCD_DISP_START|loop,CHIP1|CHIP2);	// change start position of first line(looks like its scrolling)
		_delay_ms(40);_delay_ms(40);
		_delay_ms(40);_delay_ms(40);
		_delay_ms(40);_delay_ms(40);
		if (loop==64)loop=0;
	}


}



//Sub-Routinen ANFANG
void IoDirection_Init(void)
{
		/*
	PA7	ADC7_NTC_100k
	PA6	ADC6_ANINA
	PA5	ADC5_ANINB

	PB4 	DO1_Reseve
	PB3	DO2_Solid_State_Relay
	PB2	DI_SW2
	PB1	DI_SW1
	PB1	DI_SW0

	PD7	DI_DATA_Thermoelement
	PD6	DO_Clock_Thermoelement
	PD5	PWMA
	PD4	PWMB_LED1
	PD3	DO_Enable_Thermoelement
	PD2	DO_LED2
	PD1	DO_TXD
	PD0	DI_RXD
	*/

	//PORTB OUTPUTS
	sbi (DDRB,DDB4);	//OUT
	sbi (DDRB,DDB3);	//OUT
	//PORTB INPUTS
	cbi (DDRB,DDB2);	//IN
	cbi (DDRB,DDB1);	//IN
	cbi (DDRB,DDB0);	//IN
	//PORTD OUTPUTS
	sbi (DDRD,DDD6);	//OUT
	sbi (DDRD,DDD5);	// 5. PIN von PORTD als Ausgang schalten (1=OUT) PWMA
	sbi (DDRD,DDD4);	// 4. PIN von PORTD als Ausgang schalten (1=OUT) PWMB
	sbi (DDRD,DDD3);	//OUT
	sbi (DDRD,DDD2);	//OUT
	sbi (DDRD,DDD1);	//OUT
	//PORTD INPUTS
	cbi (DDRD,DDD7);	//IN
	cbi (DDRD,DDD0);	//IN
}


//Uart initialisieren
void USART_Init(void)					// Funktion verifiziert 06.10.2013
{
	UBRRH = UBRR_VAL >> 8;				// Baudrate (19200)...high vor low schreiben!!!
	UBRRL = UBRR_VAL & 0xFF;

	UCSRC|=0x86;						// Asynchron 8/N/1	//b_10000110

	UCSRB |= (1<<TXEN); 				// UART TX einschalten
}

void ADC_Init(void)
{
	//ADMUX -> 	REFS1=1 REFS0=1 				-> int. 1,1V 
	//			ADLAR=0 						-> Rechtsausrichtung
	//
	//			MUX3=0 MUX2=0 MUX1=1 MUX0=0		-> ADC2
	ADMUX |= (1<<REFS1);
	ADMUX |= (1<<REFS0);
	
	ADMUX |= (1<<MUX1);	

	//ADC = (VIN * 1024) / 1,1V 


	ADCSRA |= (1<<ADEN);	//7. enable
	ADCSRA |= (1<<ADSC);	//6. start conversion
							//5.
							//4.	
							//3.	
	ADCSRA |= (1<<ADPS2);	//2. prescaler
	ADCSRA |= (1<<ADPS1);	//1. prescaler
	ADCSRA |= (1<<ADPS0);	//0. prescaler
}

uint16_t ADC_Read(uint8_t ADCPort, uint8_t numberOfMeanValue)
{
	uint16_t adcLowByte=0;
	uint16_t adcHighByte=0;
	uint16_t adcValue=0;
	uint8_t loop=0;
	uint8_t numberOfADCs=0;
	uint32_t temp32Bitxyz=0;
	uint32_t temp32Bitabc=0;

	//zuerst, den vorher gesetzten MUX-Kanal resetten
	ADMUX &= 0xf0;
	
	if ( ADCPort==2 )
	{
		ADMUX |= (1<<MUX1);	
	}
	else if ( ADCPort==1 )
	{
		ADMUX |= (1<<MUX0);	
	}
	else if ( ADCPort==3 )
	{
		ADMUX |= (1<<MUX0);
		ADMUX |= (1<<MUX1);	
	}
	_delay_us(20);

	//Analogwertaufnahme ---> Mittelung 
	//Fakten:
	//8MHz / 128 = 62500Hz -> 0,000.016s X 25 Takten -> 0,4ms pro Wandlung
	//d.h., bei 50 Wandlungen wren das: 0,4ms x 50 = 20ms
	//plus die 50 x 50us = 2,5ms	(knstliche Wartezeit von 50us)
	//plus die 50 x 20us = 1,0ms	(in ADC_Read...)
	//Summe = 23,5ms fr Mittelung ber 50 Werte

	for (loop=0; loop<numberOfMeanValue; loop++)
	{
		numberOfADCs++;
		//Setze bit ADSC auf high...starte Konvertierung
		//ADEN	ADSC	ADFR	ADIF	ADIE	ADPS2	ADPS1	ADPS0
		ADCSRA |= (1<<ADSC); 
	
		// Auf ADC Conversion warten; bit ADSC wird nach fertiger Conversion wieder auf 0 gesetzt
		while ( ADCSRA & _BV(ADSC) ) {}

		// ADC auslesen
		adcLowByte = ADCL; 					// immer zuerst LOW Byte lesen damit sichergestellt ist, dass LB und HB aus einem Sample stammen
    	adcLowByte &= 0x00FF;				// Maske (knnte man sich theoretisch sparen)
		adcHighByte = ADCH; 				// danach das mittlerweile gesperrte High Byte
	
		adcHighByte <<= 8;					// Schiebe um ein Byte nach links
		adcHighByte &= 0xFF00;				// Maske	

		adcValue=adcLowByte | adcHighByte; 	// bitweise verodern
		adcValue&=0x03FF;					// Maske fr 10bit Linitierung in 16bit intereger unterzubringen
	
		_delay_us(50);
		temp32Bitxyz = temp32Bitxyz + adcValue;
	}
	temp32Bitabc = temp32Bitxyz / numberOfADCs;

	adcValue = temp32Bitabc;

	numberOfADCs=0;
	temp32Bitabc=0;
	temp32Bitxyz=0;

	return (adcValue);					// Bereich: 0x0000 bis 0x03FF (0-1023dez)
}

//ber die Uart ein Zeichen senden
void USART_putc(uint8_t byte)
{
	while(bit_is_clear(UCSRA,UDRE)); //warten auf Datenregister empty
	UDR=byte;
}


//ber die Uart einen String senden
void USART_puts(char *s)
/* print string on USART (no auto linefeed) */
{
	while (*s!=0) 
	{
		USART_putc(*s);
		s++;
	}
}

//float Zahl ber USART senden
void USART_putf(float zahl, int sges, int snach)
{
	//Ausgabe einer Fliekommazahl mit sges Gesamtstellen.
	//Hiervon sind snach Nachkommastellen.
	//Die Nachkollastellen werden gerundet.
	char buffer[16];
	dtostrf(zahl,sges,snach,buffer);
	USART_puts(buffer);
}

//int Zahl ber USART senden
void USART_puti(int zahl, int sges)
{
	//Ausgabe der Integerzahl zahl formatiert mit sges Stellen
	char buffer[17];
	uint8_t l=0,n;
	char *z=buffer;
	itoa(zahl,buffer,10);
	while(*z!=0){l++; z++;}//Bufferlnge l
	for(n=l;n<sges;n++) USART_putc(' ');
	USART_puts(buffer);
}

//unsigned int Zahl ber USART senden
void USART_putui(unsigned int zahl, int sges)
{
	//Ausgabe der Integerzahl zahl formatiert mit sges Stellen
	char buffer[17];
	uint8_t l=0,n;
	char *z=buffer;
	utoa(zahl,buffer,10);
	while(*z!=0){l++; z++;}//Bufferlnge l
	for(n=l;n<sges;n++) USART_putc(' ');
	USART_puts(buffer);
}

//unsigned int Zahl ber USART senden mit Leerstellen = 0
void USART_putui_0(unsigned int zahl, int sges)
{
	//Ausgabe der Integerzahl zahl formatiert mit sges Stellen
	//Leerstellen werden mit 0 aufgefllt (TSC)
	char buffer[17];
	uint8_t l=0,n;
	char *z=buffer;
	utoa(zahl,buffer,10);
	while(*z!=0){l++; z++;}//Bufferlnge l
	for(n=l;n<sges;n++) USART_putc('0');
	USART_puts(buffer);
}

//unsigned int Zahl ber USART senden als hex-Zahl
void USART_putui_hex(unsigned int zahl, int sges)
{
	//Ausgabe der nur-positiven Integerzahl zahl formatiert mit sges Stellen
	// das Ausgabeformat ist hex (TSC)
	char buffer[17];
	uint8_t l=0,n;
	char *z=buffer;
	utoa(zahl,buffer,16);
	while(*z!=0){l++; z++;}//Bufferlnge l
	for(n=l;n<sges;n++) USART_putc(' ');
	USART_puts(buffer);
}

//unsigned int Zahl ber USART senden als bin-Zahl
void USART_putui_bin(unsigned int zahl, int sges)
{
	//Ausgabe der Integerzahl zahl formatiert mit sges Stellen
	// Das Ausgabeformat ist binr. Leerstellen werden mit 0 aufgefllt.
	char buffer[17];
	uint8_t l=0,n;
	char *z=buffer;
	utoa(zahl,buffer,2);
	while(*z!=0){l++; z++;}//Bufferlnge l
	for(n=l;n<sges;n++) USART_putc('0');
	USART_puts(buffer);
}

//Ausgabe einer 8-Bit-Zahl binr(TSC)
void USART_putb(uint8_t a)
{
	USART_putui_bin(a,8);
}

//Millisekunden wait
void wait_ms(uint16_t anzahlMilliSekunden)
{
	uint16_t i;
	for (i=0;i<=anzahlMilliSekunden;i++)
	{
		_delay_ms(1); 					//The maximal possible delay is 262.14 ms / F_CPU in MHz. = 26.214
	}
}

uint16_t takeTemperature()
{
	uint8_t i=0;
	uint16_t temperatureActLoacal=0;
 
	//CS auf low
	DO_EN_THERMOELEMENT_OFF;
	
	//16clocks + Datenaufnehmen
	//BitNr. 15
	for(i=15;i>=1;i--)
	{
		DO_Clock_THERMOELEMENT_ON;
		_delay_ms(1);
		if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	sbi(temperatureActLoacal,i);
		else 					cbi(temperatureActLoacal,i);
		DO_Clock_THERMOELEMENT_OFF;
		_delay_ms(1);
	}

	//CS auf high
	DO_EN_THERMOELEMENT_ON;	

	//Skalierung:	0-1023,75C == 0-4095
	temperatureActLoacal = temperatureActLoacal / 4;	

	return (temperatureActLoacal);
}

/*
uint16_t takeTemperature()
{
	
	uint8_t bit15=0;
	uint8_t bit14=0;
	uint8_t bit13=0;
	uint8_t bit12=0;
	uint8_t bit11=0;
	uint8_t bit10=0;
	uint8_t bit9=0;
	uint8_t bit8=0;
	uint8_t bit7=0;
	uint8_t bit6=0;
	uint8_t bit5=0;
	uint8_t bit4=0;
	uint8_t bit3=0;
	uint8_t bit2=0;
	uint8_t bit1=0;
	uint8_t bit0=0;

	uint16_t temperatureActLoacal=0;

	//CS auf low
	DO_EN_THERMOELEMENT_OFF;
	//16clocks + Datenaufnehmen
	//BitNr. 15
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit15 = 1;
	else 									bit15 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 14
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit14 = 1;
	else 									bit14 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 13
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit13 = 1;
	else 									bit13 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 12
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit12 = 1;
	else 									bit12 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 11
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit11 = 1;
	else 									bit11 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 10
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit10 = 1;
	else 									bit10 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 9
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit9 = 1;
	else 									bit9 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 8
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit8 = 1;
	else 									bit8 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 7
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit7 = 1;
	else 									bit7 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 6
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit6 = 1;
	else 									bit6 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 5
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit5 = 1;
	else 									bit5 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 4
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit4 = 1;
	else 									bit4 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 3
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit3 = 1;
	else 									bit3 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 2
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit2 = 1;
	else 									bit2 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 1
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit1 = 1;
	else 									bit1 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//BitNr. 0
	DO_Clock_THERMOELEMENT_ON;
	_delay_ms(1);
	if ( IS_DI_DATA_THERMOELEMENT_HIGH ) 	bit0 = 1;
	else 									bit0 = 0;
	DO_Clock_THERMOELEMENT_OFF;
	_delay_ms(1);
	//CS auf high
	DO_EN_THERMOELEMENT_ON;

	//Temperatur zusammenbauen
	//Bit Nr.
	//15    14    13   12   11   10   9   8   7   6  5  4  3 2 1 0
	//32768 16384 8192 4096 2048 1024 512 256 128 64 32 16 8 4 2 1
	if ( bit15 != 0 )	temperatureActLoacal = temperatureActLoacal + 32768;
	if ( bit14 != 0 )	temperatureActLoacal = temperatureActLoacal + 16384;
	if ( bit13 != 0 )	temperatureActLoacal = temperatureActLoacal + 8192;
	if ( bit12 != 0 )	temperatureActLoacal = temperatureActLoacal + 4096;
	if ( bit11 != 0 )	temperatureActLoacal = temperatureActLoacal + 2048;
	if ( bit10 != 0 )	temperatureActLoacal = temperatureActLoacal + 1024;
	if ( bit9  != 0 )	temperatureActLoacal = temperatureActLoacal + 512;
	if ( bit8  != 0 )	temperatureActLoacal = temperatureActLoacal + 256;
	if ( bit7  != 0 )	temperatureActLoacal = temperatureActLoacal + 128;
	if ( bit6  != 0 )	temperatureActLoacal = temperatureActLoacal + 64;
	if ( bit5  != 0 )	temperatureActLoacal = temperatureActLoacal + 32;
	if ( bit4  != 0 )	temperatureActLoacal = temperatureActLoacal + 16;
	if ( bit3  != 0 )	temperatureActLoacal = temperatureActLoacal + 8;
	if ( bit2  != 0 )	temperatureActLoacal = temperatureActLoacal + 4;
	if ( bit1  != 0 )	temperatureActLoacal = temperatureActLoacal + 2;
	if ( bit0  != 0 )	temperatureActLoacal = temperatureActLoacal + 1;
	//Skalierung:	0-1023,75C == 0-4095
	temperatureActLoacal = temperatureActLoacal / 4;	

	return (temperatureActLoacal);
}
*/

/*
void zeichneRohDiagramm()
{
	uint8_t i=0;

	//Y-Achse zeichnen
	for (i=1;i<53;i++) 
	{
		ks0108SetDot(20, i);
	}
	//X-Achse zeichnen
	for (i=1;i<108;i++) 
	{
		ks0108SetDot(i, 55);
	}
	//Querlinien Y-Achse zeichen
	ks0108SetDot(19, 5); ks0108SetDot(20, 5); ks0108SetDot(21, 5);  	
	ks0108SetDot(19, 13); ks0108SetDot(20, 13); ks0108SetDot(21, 13); 
	ks0108SetDot(19, 21); ks0108SetDot(20, 21); ks0108SetDot(21, 21); 
	ks0108SetDot(19, 29); ks0108SetDot(20, 29); ks0108SetDot(21, 29); 
	ks0108SetDot(19, 37); ks0108SetDot(20, 37); ks0108SetDot(21, 37); 
	ks0108SetDot(19, 45); ks0108SetDot(20, 45); ks0108SetDot(21, 45); 
	ks0108SetDot(19, 52); ks0108SetDot(20, 52); ks0108SetDot(21, 52); 
	//Querlinien X-Achse zeichen
	ks0108SetDot(27, 54); ks0108SetDot(27, 55); ks0108SetDot(27, 56); 
	ks0108SetDot(45, 54); ks0108SetDot(45, 55); ks0108SetDot(45, 56); 
	ks0108SetDot(63, 54); ks0108SetDot(63, 55); ks0108SetDot(63, 56); 
	ks0108SetDot(82, 54); ks0108SetDot(82, 55); ks0108SetDot(82, 56); 
	ks0108SetDot(99, 54); ks0108SetDot(99, 55); ks0108SetDot(9, 56); 
	ks0108SetDot(117, 54); ks0108SetDot(117, 55); ks0108SetDot(117, 56); 
	//Zahelnseperatoren X-Achsenbeschriftung setzen
	ks0108SetDot(36, 57); ks0108SetDot(37, 57); 
	ks0108SetDot(36, 64); ks0108SetDot(37, 64); 
	ks0108SetDot(54, 57); ks0108SetDot(55, 57); 
	ks0108SetDot(54, 64); ks0108SetDot(55, 64); 
	ks0108SetDot(72, 57); ks0108SetDot(73, 57); 
	ks0108SetDot(72, 64); ks0108SetDot(73, 64); 
	ks0108SetDot(90, 57); ks0108SetDot(91, 57); 
	ks0108SetDot(90, 64); ks0108SetDot(91, 64); 
	ks0108SetDot(108, 57); ks0108SetDot(109, 57); 
	ks0108SetDot(108, 64); ks0108SetDot(109, 64);
	ks0108SetDot(126, 57); 
	ks0108SetDot(126, 64);  	
	 

}
*/

/*
1.Umgebungstemperatur (20C) t0
20-155C oder 20-175C
1-1,3C/s
(104-155s)

2.
155-175C oder 175-190C
0,5C/s
(30-40s)


3.
175-232C oder 190-250C
2C/s
(30-40s)


4.Abkhlen auf Stufe 3. zurck
232-175C oder 250-190C
2C/s
(30-40s)

5.Abkhlung auf Stufe 1. Zurck
*/

